# Copyright (c) 2012, Gijs Molenaar <gijsmolenaar@gmail.com>
# Copyright (c) 2009 - 2010, Mark Bucciarelli <mkbucc@gmail.com>
# Copyright (c) 2009 Vikram Bhandoh <vikram@bhandoh.com>
#
# Permission to use, copy, modify, and/or distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

import re

from django.db.backends import util
from django.db.backends import BaseDatabaseOperations

class DatabaseOperations(BaseDatabaseOperations):
    '''
    Tells Django how to build a SQL where clauses from a Django model query.

    Also encapsulates all backend-specific differences, such
    as the way a backend performs ordering or calculates the ID of
    a recently-inserted row.
    '''

    #
    #    'endswith'        : 'LIKE %s',
    #    'iendswith'    : 'ILIKE %s',
    #    'iexact'        : 'ILIKE %s',
    #

    compiler_module = "djonet.compiler"

    operators = {
        'gt'        : '>  %s',
        'gte'        : '>= %s',
        'lt'        : '<  %s',
        'lte'        : '<= %s',
        'exact'        : '=  %s',
        'startswith'    : 'LIKE %s',
        'istartswith'    : 'ILIKE %s',
        'iexact'        : 'ILIKE %s',
        'icontains'        : 'ILIKE %s',
    }

    def quote_name(self, name):
        '''Return quoted name of table, index or column name.'''

        name = re.sub('-', '', name)

        if name.startswith('"') and name.endswith('"'):
            return name
        return '"%s"' % (name,)

    def sql_flush(self, style, tables, sequences):
        """
        Returns a list of SQL statements required to remove all data from
        the given database tables (without actually removing the tables
        themselves).

        The `style` argument is a Style object as returned by either
        color_style() or no_style() in django.core.management.color.
        """
        sql = []
        if tables:
            for table in tables:
                sql.append('%s %s;' % (style.SQL_KEYWORD('DELETE FROM'), style.SQL_FIELD(self.quote_name(table))))
        return sql


    def date_extract_sql(self, lookup_type, field_name):
        '''Given a lookup_type of 'year', 'month' or 'day',
        returns the SQL that extracts a value from the given
        date field field_name.
            '''

        return "EXTRACT(%s FROM %s)" % (lookup_type, field_name)

    def start_transaction_sql(self):
        '''MonetDB uses START TRANSACTION not BEGIN.'''

        return 'START TRANSACTION;'

    def model_to_sequencesql(self, m):
        '''Make the SQL statement that updates the tables primary
        key sequence.  Return empty string if no SQL needed.
        '''

        from django.db import connection

        # tbl has app_label prefix; e.g., testapp_simple
        tbl = m._meta.db_table

        # Get name of sequence for this table.  Here's
        # a trace from doing it manually.
        #
        #     sql>  select "default" from sys.columns 
        #     more> where table_id = 4186 and name = 'id';
        #     +-------------------------------------+
        #     | default                             |
        #     +=====================================+
        #     | next value for "django1"."seq_4176" |
        #     +-------------------------------------+
        #     1 tuple
        #     sql>
        #

        c = connection.cursor()
        fmt = '''
SELECT 
  "default" 
FROM 
  sys.columns 
WHERE 
  table_id = (SELECT id FROM sys.tables where name = %s) AND
  name = 'id'
;
'''
        c.execute(fmt, [tbl,])
        row = c.fetchone()
        # default = 'next value for "django1"."seq_4176"'
        default = row[0]
        p = default.rfind('"."seq_')
        if p == -1:
            return ''

        # seq = '"seq_4176"'
        seq = default[p + 2:]

        fmt = 'ALTER SEQUENCE %s RESTART WITH (SELECT MAX(id) + 1 FROM %s);'

        return fmt % (seq, tbl)

    def sequence_reset_sql(self, style, model_list):
        '''Return list of sequence update SQL for given models.

        Style is how to color the output for a terminal??!!'''

        from django.db import models

        fmt = "ALTER SEQUENCE %s RESTART WITH (SELECT MAX(id) + 1 FROM %s);"

        rval = []
        for model in model_list:
            sql = self.model_to_sequencesql(model)
            if sql:
                rval.append(sql)
        return rval

    def value_to_db_decimal(self, value, max_digits, decimal_places):
        """
        Transform a decimal.Decimal value to an object compatible with what is
        expected by the backend driver for decimal (numeric) columns.
        """
        if value is None:
            return None

        # monetdb only supports only 18 digitis for decimal
        max_digits = min(max_digits, 18)
        decimal_places = min(decimal_places, 17)
        return util.format_number(value, max_digits, decimal_places)

#
#    def date_trunc_sql(self, lookup_type, field_name):
#        fields = ['year', 'month', 'day', 'hour', 'minute', 'second']
#        format = ('%%Y-', '%%m', '-%%d', ' %%H:', '%%i', ':%%s') 
#        format_def = ('0000-', '01', '-01', ' 00:', '00', ':00')
#        try:
#            i = fields.index(lookup_type) + 1
#        except ValueError:
#            sql = field_name
#        else:
#            format_str = ''.join([f for f in format[:i]] + [f for f in format_def[i:]])
#            sql = "CAST(DATE_FORMAT(%s, '%s') AS DATETIME)" % (field_name, format_str)
#        return sql
#
#    def drop_foreignkey_sql(self):
#        return "DROP FOREIGN KEY"
#
#    def fulltext_search_sql(self, field_name):
#        return 'MATCH (%s) AGAINST (%%s IN BOOLEAN MODE)' % field_name
#
#    def no_limit_value(self):
#        # 2**64 - 1, as recommended by the MySQL documentation
#        return 18446744073709551615L
#

#
#    def random_function_sql(self):
#        return 'RAND()'
#
#    def sql_flush(self, style, tables, sequences):
#        # NB: The generated SQL below is specific to MySQL
#        # 'TRUNCATE x;', 'TRUNCATE y;', 'TRUNCATE z;'... style SQL statements
#        # to clear all tables of all data
#        if tables:
#            sql = ['SET FOREIGN_KEY_CHECKS = 0;']
#            for table in tables:
#                sql.append('%s %s;' % (style.SQL_KEYWORD('TRUNCATE'), style.SQL_FIELD(self.quote_name(table))))
#            sql.append('SET FOREIGN_KEY_CHECKS = 1;')
#
#            # 'ALTER TABLE table AUTO_INCREMENT = 1;'... style SQL statements
#            # to reset sequence indices
#            sql.extend(["%s %s %s %s %s;" % \
#                (style.SQL_KEYWORD('ALTER'),
#                 style.SQL_KEYWORD('TABLE'),
#                 style.SQL_TABLE(self.quote_name(sequence['table'])),
#                 style.SQL_KEYWORD('AUTO_INCREMENT'),
#                 style.SQL_FIELD('= 1'),
#                ) for sequence in sequences])
#            return sql
#        else:
#            return []
#
#    def value_to_db_datetime(self, value):
#        if value is None:
#            return None
#        
#        # MySQL doesn't support tz-aware datetimes
#        if value.tzinfo is not None:
#            raise ValueError("MySQL backend does not support timezone-aware datetimes.")
#
#        # MySQL doesn't support microseconds
#        return unicode(value.replace(microsecond=0))
#
#    def value_to_db_time(self, value):
#        if value is None:
#            return None
#            
#        # MySQL doesn't support tz-aware datetimes
#        if value.tzinfo is not None:
#            raise ValueError("MySQL backend does not support timezone-aware datetimes.")
#        
#        # MySQL doesn't support microseconds
#        return unicode(value.replace(microsecond=0))
#
#    def year_lookup_bounds(self, value):
#        # Again, no microseconds
#        first = '%s-01-01 00:00:00'
#        second = '%s-12-31 23:59:59.99'
#        return [first % value, second % value]



# Copyright (c) 2012, Gijs Molenaar <gijsmolenaar@gmail.com>
# Copyright (c) 2009 - 2010, Mark Bucciarelli <mkbucc@gmail.com>
# Copyright (c) 2009 Vikram Bhandoh <vikram@bhandoh.com>
# 
# Permission to use, copy, modify, and/or distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
# 
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#
 
from django.db.backends import *
from django.conf import settings

import monetdb.sql as Database

from djonet.introspection import DatabaseIntrospection
from djonet.creation import DatabaseCreation
from djonet.operations import DatabaseOperations
from djonet.features import DatabaseFeatures
from djonet.validation import DatabaseValidation

DatabaseError = Database.DatabaseError
IntegrityError = Database.IntegrityError

class DatabaseWrapper(BaseDatabaseWrapper):
    operators = DatabaseOperations.operators

    def __init__(self, *args, **kwargs):
        super(DatabaseWrapper, self).__init__(*args, **kwargs)

        self.features = DatabaseFeatures(self)
        self.ops = DatabaseOperations(self)
        self.validation = DatabaseValidation(self)
        self.introspection = DatabaseIntrospection(self)
        self.creation = DatabaseCreation(self)

    def _cursor(self):
        settings_dict = self.settings_dict
        kwargs = {}
        if not self.connection:
            if settings_dict['USER']:
                kwargs['username'] = settings_dict['USER']
            if settings_dict['NAME']:
                kwargs['database'] = settings_dict['NAME']
            if settings_dict['PASSWORD']:
                kwargs['password'] = settings_dict['PASSWORD']
            if settings_dict['HOST']:
                kwargs['hostname'] = settings_dict['HOST']
            if settings_dict['PORT']:
                kwargs['port'] = int(settings_dict['PORT'])

            self.connection = Database.connect(**kwargs)

        cursor = self.connection.cursor()
        cursor.arraysize = 1000
    	return cursor



# Copyright (c) 2012, Gijs Molenaar <gijsmolenaar@gmail.com>
# Copyright (c) 2009 - 2010, Mark Bucciarelli <mkbucc@gmail.com>
# Copyright (c) 2009 Vikram Bhandoh <vikram@bhandoh.com>
#
# Permission to use, copy, modify, and/or distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

from django.db.backends import BaseDatabaseFeatures

class DatabaseFeatures(BaseDatabaseFeatures):

    #
    # I'm not sure about this one.  If MonetDB can select from a table
    # it's updating, then we can leave this as the default of True.
    # Setting it to False is slower but will always work.  See
    # Django's source file db/models/sql/subqueries.py for the only place
    # this is used.
    #

    # TODO: disabled by Gijs since not sure if we need it
    #update_can_self_select = False

    #
    # Again, I'm not sure about this, so I'll use the more conservative
    # settings.
    #
    # Here's a relevant comment from the only file that uses this setting:
    # db/models/fields/related.py:
    #
    #     The database column type of a ForeignKey is the column type
    #     of the field to which it points. An exception is if the
    #     ForeignKey points to an AutoField / PositiveIntegerField /
    #     PositiveSmallIntegerField, in which case the column type
    #     is simply that of an IntegerField.  If the database needs
    #     similar types for key fields however, the only thing we can
    #     do is making AutoField an IntegerField.
    #

    # TODO: disabled by Gijs since not sure if we need it
    #related_fields_match_type = False

    # yes we need to rollback before the cursor can be used again
    requires_rollback_on_dirty_transaction = True

    #has_bulk_insert = True

    # no we can not add a reference to a foreign key if the target doesn't exist
    supports_forward_references = False


# Copyright (c) 2012, Gijs Molenaar <gijsmolenaar@gmail.com>
# Copyright (c) 2009 - 2010, Mark Bucciarelli <mkbucc@gmail.com>
# Copyright (c) 2009 Vikram Bhandoh <vikram@bhandoh.com>
#
# Permission to use, copy, modify, and/or distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#


from django.db.backends import BaseDatabaseIntrospection

class DatabaseIntrospection(BaseDatabaseIntrospection):

    data_types_reverse = {
        'boolean'    : 'BooleanField',
        'varchar'    : 'CharField',
        'date'       : 'DateField',
        'timestamp'  : 'DateTimeField',
        'numeric'    : 'FloatField',
        'double'    : 'FloatField',
        'int'        : 'IntegerField',
        'smallint'   : 'IntegerField',
        'clob'       : 'TextField',
        'time'       : 'TimeField',
	    'tinyint'	: 'SmallIntegerField',
	    'char'	: 'CharField',
    }

    def get_table_description(self, cursor, table_name):
        "Returns a description of the table, with the DB-API cursor.description interface."
        cursor.execute("SELECT * FROM %s LIMIT 1" % self.connection.ops.quote_name(table_name))
        return cursor.description

    def get_table_list(self, cursor):
        '''Return a list of table names in the current database.'''
        cursor.execute("SELECT name FROM sys.tables WHERE NOT system;")
        return [row[0] for row in cursor.fetchall()]

    def _name_to_index(self, cursor, table_name):
        """
        Returns a dictionary of {field_name: field_index} for the given table.
        Indexes are 0-based.
        """
        return dict([(d[0], i) for i, d in enumerate(self.get_table_description(cursor, table_name))])

    def get_relations(self, cursor, table_name):
        """
        Returns a dictionary of {field_index: (field_index_other_table, other_table)}
        representing all relationships to the given table. Indexes are 0-based.
        """
        my_field_dict = self._name_to_index(cursor, table_name)
        constraints = self.get_key_columns(cursor, table_name)
        relations = {}
        for my_fieldname, other_table, other_field in constraints:
            other_field_index = self._name_to_index(cursor, other_table)[other_field]
            my_field_index = my_field_dict[my_fieldname]
            relations[my_field_index] = (other_field_index, other_table)
        return relations

    def get_indexes(self, cursor, table_name):
        """
        Returns a dictionary of fieldname -> infodict for the given table,
        where each infodict is in the format:
            {'primary_key': boolean representing whether it's the primary key,
             'unique': boolean representing whether it's a unique index}

             note: monetdb doesn't support indexes
        """

        return {}

    def get_key_columns(self, cursor, table_name):
        """
        Returns a list of (column_name, referenced_table_name,
        referenced_column_name) for all key columns in given table.
        """
        cursor.execute(
"""                          SELECT "fkkc"."name",
                                 "pkt"."name",
                                 "pkkc"."name"
                          FROM "sys"."_tables" "fkt",
                               "sys"."objects" "fkkc",
                               "sys"."keys" "fkk",
                               "sys"."_tables" "pkt",
                               "sys"."objects" "pkkc",
                               "sys"."keys" "pkk",
                               "sys"."schemas" "ps",
                               "sys"."schemas" "fs" 
                         WHERE "fkt"."id" = "fkk"."table_id" AND 
                                "pkt"."id" = "pkk"."table_id" AND 
                                "fkk"."id" = "fkkc"."id" AND 
                                "pkk"."id" = "pkkc"."id" AND 
                                "fkk"."rkey" = "pkk"."id" AND
                                "fkkc"."nr" = "pkkc"."nr" AND 
                                "pkt"."schema_id" = "ps"."id" AND 
                                "fkt"."schema_id" = "fs"."id" AND 
                                "fkt"."name" = '%s'""" % (table_name,))
        result = cursor.fetchall()
        return result

    def get_primary_key_column(self, cursor, table_name):
        """
        Returns the name of the primary key column for the given table
        """
        cursor.execute("""
SELECT "objects"."name" AS "COLUMN_NAME"
                 FROM "sys"."keys" AS "keys",
                         "sys"."objects" AS "objects",
                         "sys"."tables" AS "tables",
                         "sys"."schemas" AS "schemas"
                 WHERE "keys"."id" = "objects"."id"
                         AND "keys"."table_id" = "tables"."id"
                         AND "tables"."schema_id" = "schemas"."id"
                         AND "keys"."type" = 0
                         AND "tables"."name"='%s'""" % (table_name,))
        result =  cursor.fetchall()
        if result:
            return result[0][0]


    def get_indexes(self, cursor, table_name):
         """
         Returns a dictionary of fieldname -> infodict for the given table,
         where each infodict is in the format:
             {'primary_key': boolean representing whether it's the primary key,
              'unique': boolean representing whether it's a unique index}
         """

         cols = [col[0] for col in self.get_table_description(cursor, table_name)]
         props = {col: {'primary_key': False, 'unique': False} for col in cols}
         index = self.get_primary_key_column(cursor, table_name)
         if index:
            props[index]['primary_key'] = True
         return props


# Copyright (c) 2012, Gijs Molenaar <gijsmolenaar@gmail.com>
# Copyright (c) 2009 - 2010, Mark Bucciarelli <mkbucc@gmail.com>
# Copyright (c) 2009 Vikram Bhandoh <vikram@bhandoh.com>
#
# Permission to use, copy, modify, and/or distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#


import subprocess
import sys

#from django.conf import settings
from django.db.backends.creation import BaseDatabaseCreation

class DatabaseCreation(BaseDatabaseCreation):

    #
    # XXX: I didn't see where to define the max int values that fit
    # XXX: in the int fields.  The Positive* variants will hold less
    # XXX: than expected, as they use same type as the non-Positive*
    # XXX: ones.
    #

    #
    # Careful with things like %(max_digits)s.  If Django does not
    # require the property, then db_type() will return None (as
    # there will be a key error with the data dictionary, and the
    # field will not be added to the database table!
    #

    data_types = {
        'AutoField'			: 'int AUTO_INCREMENT',
        'BooleanField'		: 'boolean',
        'CharField'			: 'varchar(%(max_length)s)',
        'CommaSeparatedIntegerField': 'varchar(%(max_length)s)',
        'DateField'			: 'date',
        'DateTimeField'		: 'timestamp',
        'DecimalField'		: 'numeric(%(max_digits)s, %(decimal_places)s)',
        'FileField'			: 'varchar(%(max_length)s)',
        'FilePathField'		: 'varchar(%(max_length)s)',
        'FloatField'		: 'float',
        'IntegerField'		: 'int',
        'IPAddressField'		: 'char(15)',
        'GenericIPAddressField': 'char(39)',
        'NullBooleanField'		: 'boolean',
        'OneToOneField'		: 'int',
        'PositiveIntegerField'	: 'int',
        'PositiveSmallIntegerField'	: 'smallint',
        'SlugField'			: 'varchar(%(max_length)s)',
        'SmallIntegerField'		: 'smallint',
        'TextField'			: 'clob',
        'TimeField'			: 'time',
    }

    def _create_test_db(self, verbosity, autoclobber):
        """
        Internal implementation - creates the test db tables.
        """
        test_database_name = self._get_test_db_name()

        def create_monet_db():
            errorcode = subprocess.check_call(["monetdb", "create", test_database_name])
            if not errorcode:
                errorcode = subprocess.check_call(["monetdb", "release", test_database_name])
            if not errorcode:
                errorcode = subprocess.check_call(["monetdb", "start", test_database_name])
            return errorcode

        try:
            create_monet_db()
        except OSError, e:
            sys.stderr.write(
                "Can't find monetdb, make sure it is installed and in your PATH: %s\n" % e)
            import os
            sys.stderr.write(os.environ['PATH'])
            sys.exit(2)
        except subprocess.CalledProcessError, e:
            sys.stderr.write(
                "Got an error creating the test database: %s\n" % e)
            if not autoclobber:
                confirm = raw_input(
                    "Type 'yes' if you would like to try deleting the test "
                    "database '%s', or 'no' to cancel: " % test_database_name)
            if autoclobber or confirm == 'yes':
                if verbosity >= 1:
                    print ("Destroying old test database '%s'..."
                           % self.connection.alias)
                try:
                    subprocess.check_call(["monetdb", "stop", test_database_name])
                except Exception:
                    pass
                try:
                    subprocess.check_call(["monetdb", "destroy", "-f", test_database_name])
                    create_monet_db()
                except Exception, e:
                    sys.stderr.write(
                        "Got an error recreating the test database: %s\n" % e)
                    sys.exit(2)
            else:
                print "Tests cancelled."
                sys.exit(1)
        return test_database_name

    def _destroy_test_db(self, test_database_name, verbosity):
        self._prepare_for_test_db_ddl()

        try:
            subprocess.check_call(["monetdb", "stop", test_database_name])
        except Exception:
            pass
        try:
            subprocess.check_call(["monetdb", "destroy", "-f", test_database_name])
        except Exception, e:
            sys.stderr.write("Got an error destroying the test database: %s\n" % e)



#!/usr/bin/env python

from distutils.core import setup

setup(name='djonet',
    version='0.2',
    description='MonetDB backend for Django',
    author='Gijs Molenaar',
    author_email='gijsmolenaar@gmail.com',
    url='https://github.com/gijzelaerr/djonet',
    packages=['djonet'],
    requires=['monetdb', 'django']
)
